# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/07_math.ipynb.

# %% auto 0
__all__ = ['MIN', 'MAX', 'SUM', 'STD', 'VAR', 'NORM', 'MEAN', 'MEDIAN', 'CENTROID']

# %% ../nbs/07_math.ipynb 5
MIN = 'min'
MAX = 'max'
SUM = 'sum'
STD = 'std'
VAR = 'var'
NORM = 'norm'
MEAN = 'mean'
MEDIAN = 'median'
CENTROID = 'centroid'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/62_pddf.ipynb.

# %% auto 0
__all__ = ['DF', 'DS', 'DX', 'DATA', 'ASTYPE', 'DATASET', 'DATAFRAME', 'IDX', 'INDEX', 'CAT', 'CATS', 'NCAT', 'CATEGORY',
           'CATEGORIES', 'COL', 'COLS', 'NCOL', 'COLUMNS', 'ROW', 'ROWS', 'NROW', 'GET', 'SHAPE', 'LOC', 'CLOC', 'ILOC',
           'ICAT']

# %% ../nbs/62_pddf.ipynb 5
DF = 'df'
DS = 'ds'
DX = 'dx'
DATA = 'data'

ASTYPE = 'astype'
DATASET = f'{DATA}set'
DATAFRAME = f'{DATA}frame'

# %% ../nbs/62_pddf.ipynb 6
IDX = 'idx'
INDEX = 'index'

# %% ../nbs/62_pddf.ipynb 7
CAT = 'cat'
CATS = f'{CAT}s'
NCAT = f'n{CAT}'

CATEGORY = f'{CAT}egory'
CATEGORIES = f'{CAT}egories'

# %% ../nbs/62_pddf.ipynb 8
COL = 'col'
COLS = f'{COL}s'
NCOL = f'n{COL}'
COLUMNS = f'{COL}umns'

# %% ../nbs/62_pddf.ipynb 9
ROW = 'row'
ROWS = f'{ROW}s'
NROW = f'n{ROW}'

# %% ../nbs/62_pddf.ipynb 10
GET = 'get'
SHAPE = f'shape'

# %% ../nbs/62_pddf.ipynb 11
LOC = 'loc'
CLOC = f'c{LOC}'
ILOC = f'i{LOC}'
ICAT = f'i{CAT}'



__version__ = "0.0.62"
# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00__init__.ipynb.

# %% auto 0
__all__ = []

# %% ../nbs/00__init__.ipynb 3
from itertools import chain

from nlit import (
    args, sund, dund, vals, errs, math as mmod, attr, dict as dmod, 
    plot, clrs, exps, mthd, embs, biol, 
    cell, fmtx, path, exts, tree, mods, 
    docs, nbks, vers, pkgs, narr, tens, pddf,
    unit, expo, byte, bkts, hrdw
)
from .args import *
from .sund import *
from .dund import *
from .vals import *
from .errs import *
from .math import *
from .attr import *
from .dict import *
from .plot import *
from .clrs import *
from .exps import *
from .mthd import *
from .embs import *
from .biol import *
from .cell import *
from .fmtx import *
from .path import *
from .exts import *
from .tree import *
from .mods import *
from .docs import *
from .nbks import *
from .vers import *
from .pkgs import *
from .narr import *
from .tens import *
from .pddf import *
from .unit import *
from .expo import *
from .byte import *
from .bkts import *
from .hrdw import *

# %% ../nbs/00__init__.ipynb 4
for mod in (sund, dund):
    for k in filter(str.isupper, dir(dund)):
        globals()[k] = getattr(dund, k)
        dund.__all__.append(k)

# %% ../nbs/00__init__.ipynb 5
__all__ = sorted(set(chain(*[
    mod.__all__ for mod in (
        args, sund, dund, vals, errs, mmod, attr, dmod, plot, clrs, exps, mthd, embs, biol, cell, fmtx, path, exts, tree, mods, 
        docs, nbks, vers, pkgs, narr, tens, pddf, unit, expo, byte, bkts, hrdw, 
    )
])))



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/101_hrdw.ipynb.

# %% auto 0
__all__ = ['PI', 'GPFS', 'GIBBS', 'IZALITH', 'MCCLEARY', 'USER_DATA', 'GPFS_GIBBS_PI']

# %% ../nbs/101_hrdw.ipynb 4
from nchr import TILDE
from .path import DATA

# %% ../nbs/101_hrdw.ipynb 7
PI = 'pi'
GPFS = 'gpfs'
GIBBS = 'gibbs'
IZALITH = 'izalith'
MCCLEARY = 'mccleary'

USER_DATA = f'{TILDE}/{DATA.capitalize()}'
GPFS_GIBBS_PI = f'/{GPFS}/{GIBBS}/{PI}'
